.. MarioBros documentation master file, created by
   sphinx-quickstart on Tue May 12 11:40:32 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MarioBros's documentation!
=====================================

Contents:

.. toctree::
    :maxdepth: 2

    mariobros.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

